[![](https://img.shields.io/travis/CiscoUcs/ucsmsdk.svg)](https://travis-ci.org/CiscoUcs/ucsmsdk)
[![](https://ucspython.herokuapp.com/badge.svg)](https://ucspython.herokuapp.com)
[![](https://img.shields.io/pypi/v/ucsmsdk.svg)](https://pypi.python.org/pypi/ucsmsdk)
[![Code Climate](https://codeclimate.com/github/CiscoUcs/ucsmsdk/badges/gpa.svg)](https://codeclimate.com/github/CiscoUcs/ucsmsdk)
[![Documentation Status](https://readthedocs.org/projects/ucsmsdk/badge/?version=latest)](http://ucsmsdk.readthedocs.io/en/latest/?badge=latest)

# Python SDK for Cisco UCS

* Apache License, Version 2.0 (the "License")
* Documentation: http://ucsmsdk.readthedocs.io/

## Installation

The SDK can be installed using any of ways below,

### From pip:

Installs the last released version,

```
    pip install ucsmsdk
```

### From github:

Installs the latest top of the tree development version,

```
    # Install pip (skip if pip is already available):
    wget https://bootstrap.pypa.io/get-pip.py
    python get-pip.py

    git clone https://github.com/CiscoUcs/ucsmsdk.git
    cd ucsmsdk
    make install
```

## Documentation

* https://github.com/ciscoucs/ucsm_apis provides APIs for many Ucs operations.
* We encourage contributions to the ucsm_apis repository


## Community:

* We are on Slack - slack requires registration, but the ucspython team is open invitation to
  anyone to register [here](https://ucspython.herokuapp.com)
